# NM53

create and update backups of GitHub repositories of a user

This program by default only lists commands, but can execute them. See `--help` for documentation on this.

# setup

```Bash
pip install NM53
```

# usage

```Bash
NM53 --help
```

```Bash
NM53 --user=wdbm
```
